aboutsummaryrefslogtreecommitdiff
path: root/src/crepe/api
diff options
context:
space:
mode:
Diffstat (limited to 'src/crepe/api')
-rw-r--r--src/crepe/api/LoopManager.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/crepe/api/LoopManager.cpp b/src/crepe/api/LoopManager.cpp
index cd602d8..46831e8 100644
--- a/src/crepe/api/LoopManager.cpp
+++ b/src/crepe/api/LoopManager.cpp
@@ -54,8 +54,8 @@ void LoopManager::loop() {
timer.enforce_frame_rate();
- // Stop the game after 5 seconds, for testing purposes
- if (timer.get_current_time() > 5) {
+ // Stop the game after 10 seconds, for testing purposes
+ if (timer.get_current_time() > 10) {
this->game_running = false;
}
}